Module http

Module http 

Available on crate features rest-client or rpc-client only.
Simple HTTP implementation which supports both async and traditional execution environments with minimal dependencies. This is used as the basis for REST and RPC clients.

Structs

BinaryResponse
An HTTP response body in binary format.
HttpError
HTTP error consisting of a status code and body contents.
JsonResponse
An HTTP response body in JSON format.

Enums

HttpClientError
Error type for HTTP client operations.

Traits

ToParseErrorMessage
Trait for converting parse errors into a String message.