pub struct BinaryResponse(pub Vec<u8>);
Available on crate features rest-client or rpc-client only.
An HTTP response body in binary format.
Interprets bytes from an HTTP response body as binary data.
The type returned in the event of a conversion error.
Performs the conversion.
Parses binary data as a block.
The type returned in the event of a conversion error.
Performs the conversion.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.