Module poll

Module poll 

Adapters that make one or more BlockSources simpler to poll for new chain tip transitions.

Structs

ChainPoller
The canonical Poll implementation used for a single BlockSource.
ValidatedBlock
A block with validated data against its transaction list and corresponding block hash.
ValidatedBlockHeader
A block header with validated proof of work and corresponding block hash.

Enums

ChainTip
A chain tip relative to another chain tip in terms of block hash and chainwork.

Traits

Poll
The Poll trait defines behavior for polling block sources for a chain tip and retrieving related chain data. It serves as an adapter for BlockSource.
Validate
The Validate trait defines behavior for validating chain data.