BlockHeaderData

Struct BlockHeaderData 

pub struct BlockHeaderData {
    pub header: Header,
    pub height: u32,
    pub chainwork: Work,
}
A block header and some associated data. This information should be available from most block sources (and, notably, is available in Bitcoin Core’s RPC and REST interfaces).

Fields

header: Header

The block header itself.

height: u32

The block height where the genesis block has height 0.

chainwork: Work

The total chain work required to build a chain of equivalent weight.