Struct lightning_block_sync::BlockSourceError
source · [−]pub struct BlockSourceError { /* private fields */ }Expand description
Error type for BlockSource requests.
Transient errors may be resolved when re-polling, but no attempt will be made to re-poll on persistent errors.
Implementations
sourceimpl BlockSourceError
impl BlockSourceError
sourcepub fn persistent<E>(error: E) -> Self where
E: Into<Box<dyn Error + Send + Sync>>,
pub fn persistent<E>(error: E) -> Self where
E: Into<Box<dyn Error + Send + Sync>>,
Creates a new persistent error originated from the given error.
sourcepub fn transient<E>(error: E) -> Self where
E: Into<Box<dyn Error + Send + Sync>>,
pub fn transient<E>(error: E) -> Self where
E: Into<Box<dyn Error + Send + Sync>>,
Creates a new transient error originated from the given error.
sourcepub fn kind(&self) -> BlockSourceErrorKind
pub fn kind(&self) -> BlockSourceErrorKind
Returns the kind of error.