Available on crate features
rest-client or rpc-client only.Expand description
Simple HTTP implementation which supports both async and traditional execution environments with minimal dependencies. This is used as the basis for REST and RPC clients.
Structs
- Binary
Response - An HTTP response body in binary format.
- Http
Error - HTTP error consisting of a status code and body contents.
- Json
Response - An HTTP response body in JSON format.
Enums
- Http
Client Error - Error type for HTTP client operations.
Traits
- ToParse
Error Message - Trait for converting parse errors into a String message.